@@ -1,7 +1,7 @@
 import time
 
-from raepy.servo.LSS_Library_Python import lss
-from raepy.servo.LSS_Library_Python import lssc
+from .LSS_Library_Python import lss
+from .LSS_Library_Python import lssc
 
 from serial.serialutil import SerialException
 
@@ -74,6 +74,9 @@ class Servo(object):
             9:'Blocked',
             10:'Safe Mode'
         }
+    
+    def __del__(self):
+        self.limp()
 
     def init_interface(self, dev_string):
         lss.initBus(dev_string,self._CST_LSS_Baud)
